Guides — SynDisco 2.0.4 documentation

# Guides

We provide three short tutorials on how to use Syndisco. At the end of these tutorials, you will understand how to set up and execute a synthetic discussion, annotate it, as well as how to generate and manage up to hundereds of discussions.

The code for each of these guides can also be found on the project’s repository.

## How to Create a Synthetic Discussion

Basic setup including setting up models, actors and turn-taking strategies.

## How to Annotate your Synthetic Discussions

## How to Use the Experiment API to Manage Large-Scale Studies

Also includes features such as logging and exporting synthetic datasets to CSV format.